"""Market Order v1 package."""

# ===================================================================
# AUTO-GENERATED SECTION - ONLY EDIT BELOW THE CLOSING COMMENT BLOCK
# ===================================================================
# This section is automatically managed by protoc-gen-meshpy.
#
# DO NOT EDIT ANYTHING IN THIS SECTION MANUALLY!
# Your changes will be overwritten during code generation.
#
# To add custom imports and exports, scroll down to the
# "MANUAL SECTION" indicated below.
# ===================================================================

# Generated protobuf imports
from .market_order_pb2 import MarketOrder
from .service_pb2 import GetMarketOrderRequest

# Generated service imports
from .service_meshpy import (
    MarketOrderService,
    MarketOrderServiceGRPCClient,
    MarketOrderServiceGRPCClientInterface,
)

# ===================================================================
# END OF AUTO-GENERATED SECTION
# ===================================================================
#
# MANUAL SECTION - ADD YOUR CUSTOM IMPORTS AND EXPORTS BELOW
#
# You can safely add your own imports, functions, classes, and exports
# in this section. They will be preserved across code generation.
#
# Example:
#   from my_custom_module import my_function
#
# ===================================================================

# ===================================================================
# MODULE EXPORTS
# ===================================================================
# Combined auto-generated and manual exports
__all__ = [
    # Generated exports
    "GetMarketOrderRequest",
    "MarketOrder",
    "MarketOrderService",
    "MarketOrderServiceGRPCClient",
    "MarketOrderServiceGRPCClientInterface",
]



"""
ApiUserService interface definition.
"""

from abc import ABC, abstractmethod
from datetime import timedelta

from .api_user_pb2 import APIUser
from .service_pb2 import (
    ActivateApiUserRequest,
    CreateApiUserRequest,
    DeactivateApiUserRequest,
    GetApiUserByKeyHashRequest,
    GetApiUserRequest,
    ListApiUsersRequest,
    ListApiUsersResponse,
    SearchApiUsersRequest,
    SearchApiUsersResponse,
)


class ApiUserService(ABC):
    """Abstract base class defining the ApiUserService interface."""

    @abstractmethod
    def get_api_user(self, request: GetApiUserRequest, timeout: timedelta | None = None) -> APIUser:
        """Get an API user by name."""
        pass

    @abstractmethod
    def create_api_user(self, request: CreateApiUserRequest, timeout: timedelta | None = None) -> APIUser:
        """Create a new API user."""
        pass

    @abstractmethod
    def list_api_users(self, request: ListApiUsersRequest, timeout: timedelta | None = None) -> ListApiUsersResponse:
        """List API users."""
        pass

    @abstractmethod
    def search_api_users(self, request: SearchApiUsersRequest, timeout: timedelta | None = None) -> SearchApiUsersResponse:
        """Search API users by display name."""
        pass

    @abstractmethod
    def activate_api_user(self, request: ActivateApiUserRequest, timeout: timedelta | None = None) -> APIUser:
        """Activate an API user."""
        pass

    @abstractmethod
    def deactivate_api_user(self, request: DeactivateApiUserRequest, timeout: timedelta | None = None) -> APIUser:
        """Deactivate an API user."""
        pass

    @abstractmethod
    def get_api_user_by_key_hash(self, request: GetApiUserByKeyHashRequest, timeout: timedelta | None = None) -> APIUser:
        """Get an API user by key hash."""
        pass



from meshtrade.iam.role.v1 import role_pb2 as _role_pb2
from meshtrade.option.v1 import method_type_pb2 as _method_type_pb2
from meshtrade.trading.limit_order.v1 import limit_order_pb2 as _limit_order_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class GetLimitOrderRequest(_message.Message):
    __slots__ = ("number",)
    NUMBER_FIELD_NUMBER: _ClassVar[int]
    number: str
    def __init__(self, number: _Optional[str] = ...) -> None: ...
